@@ -1,8 +1,10 @@
 /// A local host only for serving static files.
 /// Simple and easy, but not robust or tested.
-extern crate native_tls;
 
+#[cfg(feature = "https")]
 use native_tls::{Identity, TlsAcceptor};
+#[cfg(feature = "https")]
+use std::sync::Arc;
 
 use std::ffi::OsStr;
 use std::fs;
@@ -11,7 +13,6 @@ use std::io::{Read, Write};
 use std::net::TcpListener;
 use std::path::Path;
 use std::str;
-use std::sync::Arc;
 use std::thread;
 
 #[cfg(feature = "reload")]
@@ -30,6 +31,7 @@ pub fn read_header<T: Read + Write>(stream: &mut T) -> Vec<u8> {
     buffer
 }
 
+#[allow(unused)]
 fn handle_client<T: Read + Write>(mut stream: T, root_path: &str, reload: bool, headers: &str) {
     let buffer = read_header(&mut stream);
     let request_string = str::from_utf8(&buffer).unwrap();
@@ -37,13 +39,19 @@ fn handle_client<T: Read + Write>(mut stream: T, root_path: &str, reload: bool,
     if request_string.is_empty() {
         return;
     }
+
     // Split the request into different parts.
     let mut parts = request_string.split(' ');
 
     let _method = parts.next().unwrap().trim();
-    let path = parts.next().unwrap().trim();
+    let mut path = parts.next().unwrap().trim();
     let _http_version = parts.next().unwrap().trim();
 
+    // Trim parameters from URL
+    if let Some(parameters_index) = path.find('?') {
+        path = &path[..parameters_index];
+    }
+
     // Replace white space characters with proper whitespace and remove any paths that refer to the parent.
     let path = path.replace("../", "").replace("%20", " ");
     let path = if path.ends_with("/") {
@@ -76,6 +84,8 @@ fn handle_client<T: Read + Write>(mut stream: T, root_path: &str, reload: bool,
     if let Ok(mut file_contents) = file_contents {
         // Pair the file extension to a media (also known as MIME) type.
         let content_type = extension_to_mime_impl(extension);
+
+        #[allow(unused_mut)]
         let mut content_length = file_contents.len();
 
         // Prepare to inject code into HTML if reload is enabled.
@@ -116,15 +126,16 @@ fn handle_client<T: Read + Write>(mut stream: T, root_path: &str, reload: bool,
 }
 
 pub fn run(address: &str, port: u32, path: &str, reload: bool, headers: &str) {
-    // Hard coded certificate generated with the following commands:
-    // openssl req -x509 -newkey rsa:2048 -keyout key.pem -out cert.pem -days 36500 -nodes -subj "/"
-    // openssl pkcs12 -export -out identity.pfx -inkey key.pem -in cert.pem
-    // password for second command: 'debug'
-    let bytes = include_bytes!("identity.pfx");
-    let identity = Identity::from_pkcs12(bytes, "debug").unwrap();
-
-    let acceptor = TlsAcceptor::new(identity).unwrap();
-    let acceptor = Arc::new(acceptor);
+    #[cfg(feature = "https")]
+    let acceptor = {
+        // Hard coded certificate generated with the following commands:
+        // openssl req -x509 -newkey rsa:2048 -keyout key.pem -out cert.pem -days 36500 -nodes -subj "/"
+        // openssl pkcs12 -export -out identity.pfx -inkey key.pem -in cert.pem
+        // password for second command: 'debug'
+        let bytes = include_bytes!("identity.pfx");
+        let identity = Identity::from_pkcs12(bytes, "debug").unwrap();
+        Arc::new(TlsAcceptor::new(identity).unwrap())
+    };
 
     #[cfg(feature = "reload")]
     {
@@ -141,7 +152,9 @@ pub fn run(address: &str, port: u32, path: &str, reload: bool, headers: &str) {
     let listener = TcpListener::bind(address_with_port).unwrap();
     for stream in listener.incoming() {
         if let Ok(stream) = stream {
+            #[cfg(feature = "https")]
             let acceptor = acceptor.clone();
+
             let path = path.to_owned();
             let headers = headers.to_owned();
             thread::spawn(move || {
@@ -151,11 +164,16 @@ pub fn run(address: &str, port: u32, path: &str, reload: bool, headers: &str) {
                 let mut buf = [0; 2];
                 stream.peek(&mut buf).expect("peek failed");
 
+                #[cfg(feature = "https")]
                 let is_https =
                     !((buf[0] as char).is_alphabetic() && (buf[1] as char).is_alphabetic());
 
+                #[cfg(not(feature = "https"))]
+                let is_https = false;
+
                 if is_https {
                     // acceptor.accept will block indefinitely if called with an HTTP stream.
+                    #[cfg(feature = "https")]
                     if let Ok(stream) = acceptor.accept(stream) {
                         handle_client(stream, &path, reload, &headers);
                     }
